==> qt6-qtwayland-6.3.1.tgz: lib/cmake/Qt6WaylandCompositor/Qt6WaylandCompositorConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was QtModuleConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

cmake_minimum_required(VERSION 3.16...3.21)

include(CMakeFindDependencyMacro)

get_filename_component(_import_prefix "${CMAKE_CURRENT_LIST_FILE}" PATH)
get_filename_component(_import_prefix "${_import_prefix}" REALPATH)

# Extra cmake code begin

# Extra cmake code end

# Find required dependencies, if any.
if(EXISTS "${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorDependencies.cmake")
    include("${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorDependencies.cmake")
endif()

# If *ConfigDependencies.cmake exists, the variable value will be defined there.
# Don't override it in that case.
if(NOT DEFINED "Qt6WaylandCompositor_FOUND")
    set("Qt6WaylandCompositor_FOUND" TRUE)
endif()

if (NOT QT_NO_CREATE_TARGETS AND Qt6WaylandCompositor_FOUND)
    include("${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorTargets.cmake")
    include("${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorAdditionalTargetInfo.cmake")
    if(NOT QT_NO_CREATE_VERSIONLESS_TARGETS)
        include("${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorVersionlessTargets.cmake")
    endif()

    # DEPRECATED
    # Provide old style variables for includes, compile definitions, etc.
    # These variables are deprecated and only provided on a best-effort basis to facilitate porting.
    # Consider using target_link_libraries(app PRIVATE Qt6WaylandCompositor) instead.
    set(Qt6WaylandCompositor_LIBRARIES "Qt6::WaylandCompositor")

    get_target_property(_Qt6WaylandCompositor_OWN_INCLUDE_DIRS
                        Qt6::WaylandCompositor INTERFACE_INCLUDE_DIRECTORIES)
    if(NOT _Qt6WaylandCompositor_OWN_INCLUDE_DIRS)
        set(_Qt6WaylandCompositor_OWN_INCLUDE_DIRS "")
    endif()

    if(TARGET Qt6::WaylandCompositorPrivate)
        get_target_property(_Qt6WaylandCompositor_OWN_PRIVATE_INCLUDE_DIRS
                            Qt6::WaylandCompositorPrivate INTERFACE_INCLUDE_DIRECTORIES)
        if(NOT _Qt6WaylandCompositor_OWN_PRIVATE_INCLUDE_DIRS)
            set(_Qt6WaylandCompositor_OWN_PRIVATE_INCLUDE_DIRS "")
        endif()
    endif()

    get_target_property(Qt6WaylandCompositor_DEFINITIONS
                        Qt6::WaylandCompositor INTERFACE_COMPILE_DEFINITIONS)
    if(NOT Qt6WaylandCompositor_DEFINITIONS)
        set(Qt6WaylandCompositor_DEFINITIONS "")
    else()
        list(TRANSFORM Qt6WaylandCompositor_DEFINITIONS PREPEND "-D")
    endif()

    get_target_property(Qt6WaylandCompositor_COMPILE_DEFINITIONS
                        Qt6::WaylandCompositor INTERFACE_COMPILE_DEFINITIONS)
    if(NOT Qt6WaylandCompositor_COMPILE_DEFINITIONS)
        set(Qt6WaylandCompositor_COMPILE_DEFINITIONS "")
    endif()

    set(Qt6WaylandCompositor_INCLUDE_DIRS
        ${_Qt6WaylandCompositor_OWN_INCLUDE_DIRS})

    set(Qt6WaylandCompositor_PRIVATE_INCLUDE_DIRS
        ${_Qt6WaylandCompositor_OWN_PRIVATE_INCLUDE_DIRS})

    foreach(_module_dep ${_Qt6WaylandCompositor_MODULE_DEPENDENCIES})
        list(APPEND Qt6WaylandCompositor_INCLUDE_DIRS
             ${Qt6${_module_dep}_INCLUDE_DIRS})
        list(APPEND Qt6WaylandCompositor_PRIVATE_INCLUDE_DIRS
             ${Qt6${_module_dep}_PRIVATE_INCLUDE_DIRS})
        list(APPEND Qt6WaylandCompositor_DEFINITIONS
             ${Qt6${_module_dep}_DEFINITIONS})
        list(APPEND Qt6WaylandCompositor_COMPILE_DEFINITIONS
             ${Qt6${_module_dep}_COMPILE_DEFINITIONS})
    endforeach()

    list(REMOVE_DUPLICATES Qt6WaylandCompositor_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt6WaylandCompositor_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt6WaylandCompositor_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt6WaylandCompositor_COMPILE_DEFINITIONS)
endif()

if (TARGET Qt6::WaylandCompositor)
    foreach(extra_cmake_include Qt6WaylandCompositorMacros.cmake)
        include("${CMAKE_CURRENT_LIST_DIR}/${extra_cmake_include}")
    endforeach()

    qt_make_features_available(Qt6::WaylandCompositor)

    if(EXISTS "${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorPlugins.cmake")
        include("${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorPlugins.cmake")
    endif()

    list(APPEND QT_ALL_MODULES_FOUND_VIA_FIND_PACKAGE "WaylandCompositor")

    get_target_property(_qt_module_target_type "Qt6::WaylandCompositor" TYPE)
    if(NOT _qt_module_target_type STREQUAL "INTERFACE_LIBRARY")
        get_target_property(_qt_module_plugin_types
                            Qt6::WaylandCompositor MODULE_PLUGIN_TYPES)
        if(_qt_module_plugin_types)
            list(APPEND QT_ALL_PLUGIN_TYPES_FOUND_VIA_FIND_PACKAGE "${_qt_module_plugin_types}")
        endif()
    endif()


    # Load Module's BuildInternals should any exist
    if (Qt6BuildInternals_DIR AND
        EXISTS "${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorBuildInternals.cmake")
        include("${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorBuildInternals.cmake")
    endif()
else()

    set(Qt6WaylandCompositor_FOUND FALSE)
    if(NOT DEFINED Qt6WaylandCompositor_NOT_FOUND_MESSAGE)
        set(Qt6WaylandCompositor_NOT_FOUND_MESSAGE
            "Target \"Qt6::WaylandCompositor\" was not found. ${Qt6WaylandCompositor_extra_not_found_message}")

        if(QT_NO_CREATE_TARGETS)
            string(APPEND Qt6WaylandCompositor_NOT_FOUND_MESSAGE
                "Possibly due to QT_NO_CREATE_TARGETS being set to TRUE and thus "
                "${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorTargets.cmake was not "
                "included to define the target.")
        endif()
    endif()
endif()

==> qt6-qtwayland-6.8.3.tgz: lib/cmake/Qt6WaylandCompositor/Qt6WaylandCompositorConfig.cmake <==
# Copyright (C) 2024 The Qt Company Ltd.
# SPDX-License-Identifier: BSD-3-Clause


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was QtModuleConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

cmake_minimum_required(VERSION 3.16...3.21)

include(CMakeFindDependencyMacro)

get_filename_component(_import_prefix "${CMAKE_CURRENT_LIST_FILE}" PATH)
get_filename_component(_import_prefix "${_import_prefix}" REALPATH)

# Extra cmake code begin

# Extra cmake code end

# Find required dependencies, if any.
if(EXISTS "${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorDependencies.cmake")
    include("${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorDependencies.cmake")
    _qt_internal_suggest_dependency_debugging(WaylandCompositor
        __qt_WaylandCompositor_pkg ${CMAKE_FIND_PACKAGE_NAME}_NOT_FOUND_MESSAGE)
endif()

# If *ConfigDependencies.cmake exists, the variable value will be defined there.
# Don't override it in that case.
if(NOT DEFINED "Qt6WaylandCompositor_FOUND")
    set("Qt6WaylandCompositor_FOUND" TRUE)
endif()

if (NOT QT_NO_CREATE_TARGETS AND Qt6WaylandCompositor_FOUND)
    include("${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorTargets.cmake")
    include("${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorAdditionalTargetInfo.cmake"
        OPTIONAL)
    include("${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorExtraProperties.cmake"
        OPTIONAL)

    # DEPRECATED
    # Provide old style variables for includes, compile definitions, etc.
    # These variables are deprecated and only provided on a best-effort basis to facilitate porting.
    # Consider using target_link_libraries(app PRIVATE Qt6WaylandCompositor) instead.
    set(Qt6WaylandCompositor_LIBRARIES "Qt6::WaylandCompositor")

    get_target_property(_Qt6WaylandCompositor_OWN_INCLUDE_DIRS
                        Qt6::WaylandCompositor INTERFACE_INCLUDE_DIRECTORIES)
    if(NOT _Qt6WaylandCompositor_OWN_INCLUDE_DIRS)
        set(_Qt6WaylandCompositor_OWN_INCLUDE_DIRS "")
    endif()

    if(TARGET Qt6::WaylandCompositorPrivate)
        get_target_property(_Qt6WaylandCompositor_OWN_PRIVATE_INCLUDE_DIRS
                            Qt6::WaylandCompositorPrivate INTERFACE_INCLUDE_DIRECTORIES)
        if(NOT _Qt6WaylandCompositor_OWN_PRIVATE_INCLUDE_DIRS)
            set(_Qt6WaylandCompositor_OWN_PRIVATE_INCLUDE_DIRS "")
        endif()
    endif()

    get_target_property(Qt6WaylandCompositor_DEFINITIONS
                        Qt6::WaylandCompositor INTERFACE_COMPILE_DEFINITIONS)
    if(NOT Qt6WaylandCompositor_DEFINITIONS)
        set(Qt6WaylandCompositor_DEFINITIONS "")
    else()
        set(updated_defs "")
        foreach(def IN LISTS  Qt6WaylandCompositor_DEFINITIONS)
             if(def MATCHES "^[A-Za-z_]")
                 list(APPEND updated_defs "-D${def}")
             else()
                 list(APPEND updated_defs "${def}")
             endif()
        endforeach()
        set(Qt6WaylandCompositor_DEFINITIONS "${updated_defs}")
        unset(updated_defs)
    endif()

    get_target_property(Qt6WaylandCompositor_COMPILE_DEFINITIONS
                        Qt6::WaylandCompositor INTERFACE_COMPILE_DEFINITIONS)
    if(NOT Qt6WaylandCompositor_COMPILE_DEFINITIONS)
        set(Qt6WaylandCompositor_COMPILE_DEFINITIONS "")
    endif()

    set(Qt6WaylandCompositor_INCLUDE_DIRS
        ${_Qt6WaylandCompositor_OWN_INCLUDE_DIRS})

    set(Qt6WaylandCompositor_PRIVATE_INCLUDE_DIRS
        ${_Qt6WaylandCompositor_OWN_PRIVATE_INCLUDE_DIRS})

    foreach(_module_dep ${_Qt6WaylandCompositor_MODULE_DEPENDENCIES})
        if(_module_dep MATCHES ".+Private$")
            set(_private_suffix "Private")
        else()
            set(_private_suffix "")
        endif()
        list(APPEND Qt6WaylandCompositor${_private_suffix}_INCLUDE_DIRS
             ${Qt6${_module_dep}_INCLUDE_DIRS})
        list(APPEND Qt6WaylandCompositor${_private_suffix}_PRIVATE_INCLUDE_DIRS
             ${Qt6${_module_dep}_PRIVATE_INCLUDE_DIRS})
        if(_private_suffix)
            list(APPEND Qt6WaylandCompositor_PRIVATE_INCLUDE_DIRS
                ${Qt6${_module_dep}_PRIVATE_INCLUDE_DIRS})
        endif()
        list(APPEND Qt6WaylandCompositor${_private_suffix}_DEFINITIONS
             ${Qt6${_module_dep}_DEFINITIONS})
        list(APPEND Qt6WaylandCompositor${_private_suffix}_COMPILE_DEFINITIONS
             ${Qt6${_module_dep}_COMPILE_DEFINITIONS})
    endforeach()
    unset(_private_suffix)

    list(REMOVE_DUPLICATES Qt6WaylandCompositor_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt6WaylandCompositor_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt6WaylandCompositor_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt6WaylandCompositor_COMPILE_DEFINITIONS)
endif()

if (TARGET Qt6::WaylandCompositor)
    qt_make_features_available(Qt6::WaylandCompositor)

    foreach(extra_cmake_include Qt6WaylandCompositorMacros.cmake)
        include("${CMAKE_CURRENT_LIST_DIR}/${extra_cmake_include}")
    endforeach()

    if(EXISTS "${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorPlugins.cmake")
        include("${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorPlugins.cmake")
    endif()

    if(NOT "WaylandCompositor" IN_LIST QT_ALL_MODULES_FOUND_VIA_FIND_PACKAGE)
        list(APPEND QT_ALL_MODULES_FOUND_VIA_FIND_PACKAGE "WaylandCompositor")
        list(APPEND QT_ALL_MODULES_VERSIONED_FOUND_VIA_FIND_PACKAGE
            "Qt6::WaylandCompositor")
    endif()

    get_target_property(_qt_module_target_type "Qt6::WaylandCompositor" TYPE)
    if(NOT _qt_module_target_type STREQUAL "INTERFACE_LIBRARY")
        get_target_property(_qt_module_plugin_types
                            Qt6::WaylandCompositor MODULE_PLUGIN_TYPES)
        if(_qt_module_plugin_types)
            foreach(_qt_module_plugin_type IN LISTS _qt_module_plugin_types)
                if(NOT "${_qt_module_plugin_type}"
                    IN_LIST QT_ALL_PLUGIN_TYPES_FOUND_VIA_FIND_PACKAGE)
                    list(APPEND QT_ALL_PLUGIN_TYPES_FOUND_VIA_FIND_PACKAGE
                    "${_qt_module_plugin_type}")
                endif()
            endforeach()
            unset(_qt_module_plugin_type)
        endif()
    endif()

    # Load Module's BuildInternals should any exist
    if (Qt6BuildInternals_DIR AND
        EXISTS "${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorBuildInternals.cmake")
        include("${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorBuildInternals.cmake")
    endif()

    if(NOT QT_NO_CREATE_VERSIONLESS_TARGETS)
        if(CMAKE_VERSION VERSION_LESS 3.18 OR QT_USE_OLD_VERSION_LESS_TARGETS)
            include("${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorVersionlessTargets.cmake")
        else()
            include("${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorVersionlessAliasTargets.cmake")
        endif()
    endif()
else()

    set(Qt6WaylandCompositor_FOUND FALSE)
    if(NOT DEFINED Qt6WaylandCompositor_NOT_FOUND_MESSAGE)
        set(Qt6WaylandCompositor_NOT_FOUND_MESSAGE
            "Target \"Qt6::WaylandCompositor\" was not found.")

        if(QT_NO_CREATE_TARGETS)
            string(APPEND Qt6WaylandCompositor_NOT_FOUND_MESSAGE
                "Possibly due to QT_NO_CREATE_TARGETS being set to TRUE and thus "
                "${CMAKE_CURRENT_LIST_DIR}/Qt6WaylandCompositorTargets.cmake was not "
                "included to define the target.")
        endif()
    endif()
endif()
